==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/sv/lang.php <==
<?php
/**
 * Swedish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Joaquim Homrighausen <joho@webbplatsen.se>
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell[at]mydata.se>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '”';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '’';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Redigera sidan';
$lang['btn_source']            = 'Visa källkod';
$lang['btn_show']              = 'Visa sidan';
$lang['btn_create']            = 'Skapa sidan';
$lang['btn_search']            = 'Sök';
$lang['btn_save']              = 'Spara';
$lang['btn_preview']           = 'Granska';
$lang['btn_top']               = 'Till början av sidan';
$lang['btn_newer']             = '<< nyare';
$lang['btn_older']             = 'äldre >>';
$lang['btn_revs']              = 'Historik';
$lang['btn_recent']            = 'Nyligen ändrat';
$lang['btn_upload']            = 'Ladda upp';
$lang['btn_cancel']            = 'Avbryt';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Redigera';
$lang['btn_login']             = 'Logga in';
$lang['btn_logout']            = 'Logga ut';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Uppdatera';
$lang['btn_delete']            = 'Radera';
$lang['btn_back']              = 'Tillbaka';
$lang['btn_backlink']          = 'Tillbakalänkar';
$lang['btn_backtomedia']       = 'Tillbaka till val av Mediafil';
$lang['btn_subscribe']         = 'Prenumerera på ändringar';
$lang['btn_unsubscribe']       = 'Säg upp prenumeration på ändringar';
$lang['btn_subscribens']       = 'Prenumerera på namnrymdsändringar';
$lang['btn_unsubscribens']     = 'Sluta prenumerera på namnrymdsändringar
';
$lang['btn_profile']           = 'Uppdatera profil';
$lang['btn_reset']             = 'Återställ';
$lang['btn_resendpwd']         = 'Skicka nytt lösenord';
$lang['btn_draft']             = 'Redigera utkast';
$lang['btn_recover']           = 'Återskapa utkast';
$lang['btn_draftdel']          = 'Radera utkast';
$lang['loggedinas']            = 'Inloggad som';
$lang['user']                  = 'Användarnamn';
$lang['pass']                  = 'Lösenord';
$lang['newpass']               = 'Nytt lösenord';
$lang['oldpass']               = 'Bekräfta nuvarande lösenord';
$lang['passchk']               = 'en gång till';
$lang['remember']              = 'Kom ihåg mig';
$lang['fullname']              = 'Namm';
$lang['email']                 = 'E-post';
$lang['register']              = 'Registrera';
$lang['profile']               = 'Användarprofil';
$lang['badlogin']              = 'Felaktigt användarnamn eller lösenord.';
$lang['minoredit']             = 'Små ändringar';
$lang['draftdate']             = 'Utkast automatiskt sparat';
$lang['regmissing']            = 'Du måste fylla i alla fälten.';
$lang['reguexists']            = 'Det finns redan en användare med det användarnamnet.';
$lang['regsuccess']            = 'Användarkontot skapat, lösenordet har skickats via e-post.';
$lang['regsuccess2']           = 'Användarkontot skapat.';
$lang['regmailfail']           = 'Ett fel uppstod när ditt lösenord skulle skickas via e-post. Var god kontakta administratören!';
$lang['regbadmail']            = 'Den angivna e-postadressen verkar vara ogiltig - om du anser detta felaktigt, var god kontakta administratören';
$lang['regbadpass']            = 'De två angivna lösenorden är inte identiska. Försök igen.';
$lang['regpwmail']             = 'Ditt DokuWikilösenord';
$lang['reghere']               = 'Har du inte ett konto än? Skaffa ett';
$lang['profna']                = 'Denna wiki stödjer inte ändringar av profiler';
$lang['profnochange']          = 'Ingenting ändrades, gör ingenting.';
$lang['profnoempty']           = 'Namn och e-postadress måste fyllas i.';
$lang['profchanged']           = 'Användarprofilen uppdaterad.';
$lang['pwdforget']             = 'Glömt ditt lösenord? Ordna ett nytt';
$lang['resendna']              = 'Den här wikin stödjer inte utskick av lösenord.';
$lang['resendpwd']             = 'Skicka nytt lösenord för';
$lang['resendpwdmissing']      = 'Du måste fylla i alla fält.';
$lang['resendpwdnouser']       = 'Den här användaren hittas inte i databasen.';
$lang['resendpwdbadauth']      = 'Den här verifieringskoden är inte giltig. Kontrollera att du använde hela verifieringslänken.';
$lang['resendpwdconfirm']      = 'En verifieringslänk har skickats med e-post.';
$lang['resendpwdsuccess']      = 'Ditt nya lösenord har skickats med e-post.';
$lang['txt_upload']            = 'Välj fil att ladda upp';
$lang['txt_filename']          = 'Ladda upp som (ej obligatoriskt)';
$lang['txt_overwrt']           = 'Skriv över befintlig fil';
$lang['lockedby']              = 'Låst av';
$lang['lockexpire']            = 'Lås upphör att gälla';
$lang['willexpire']            = 'Ditt redigeringslås för detta dokument kommer snart att upphöra.\nFör att undvika versionskonflikter bör du förhandsgranska ditt dokument för att förlänga redigeringslåset.';
$lang['notsavedyet']           = 'Det finns ändringar som inte är sparade.\nÄr du säker på att du vill fortsätta?';
$lang['rssfailed']             = 'Ett fel uppstod när detta RSS-flöde skulle hämtas: ';
$lang['nothingfound']          = 'Inga filer hittades.';
$lang['mediaselect']           = 'Mediafiler';
$lang['fileupload']            = 'Ladda upp mediafiler';
$lang['uploadsucc']            = 'Uppladdningen lyckades';
$lang['uploadfail']            = 'Uppladdningen misslyckades, fel filskydd?';
$lang['uploadwrong']           = 'Uppladdning nekad. Filändelsen är inte tillåten!';
$lang['uploadexist']           = 'Filen finns redan. Gjorde ingenting.';
$lang['uploadbadcontent']      = 'Det uppladdade innehållet stämde inte överens med filändelsen %s.';
$lang['uploadspam']            = 'Uppladdningen stoppades av spärrlistan för spam.';
$lang['uploadxss']             = 'Uppladdningen stoppades på grund av eventuellt skadligt innehåll.';
$lang['deletesucc']            = 'Filen "%s" har raderats.';
$lang['deletefail']            = 'Kunde inte radera "%s" - kontrollera filskydd.';
$lang['mediainuse']            = 'Filen "%s" har inte raderats - den används fortfarande.';
$lang['namespaces']            = 'Namnrymder';
$lang['mediafiles']            = 'Tillgängliga filer i';
$lang['js']['keepopen']        = 'Lämna fönstret öppet efter val av fil';
$lang['js']['hidedetails']     = 'Dölj detaljer';
$lang['mediausage']            = 'Använd följande syntax för att referera till denna fil:';
$lang['mediaview']             = 'Visa originalfilen';
$lang['mediaroot']             = 'rot';
$lang['mediaupload']           = 'Här kan du ladda upp en fil till den nuvarande namnrymden. För att skapa undernamnrymder, skriv dem före filnamnet under "Ladda upp som". Separera namnrymd och filnamn med kolon.';
$lang['mediaextchange']        = 'Filändelsen ändrad från .%s till .%s!';
$lang['reference']             = 'Referenser till';
$lang['ref_inuse']             = 'Filen kan inte raderas eftersom den fortfarande används av följande sidor:';
$lang['ref_hidden']            = 'Vissa referenser är på sidor som du inte har rätt att läsa';
$lang['hits']                  = 'Träffar';
$lang['quickhits']             = 'Matchande sidnamn';
$lang['toc']                   = 'Innehållsförteckning';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Din version';
$lang['diff']                  = 'visa skillnader mot aktuell version';
$lang['diff2']                 = 'Visa skillnader mellan valda versioner';
$lang['line']                  = 'Rad';
$lang['breadcrumb']            = 'Spår';
$lang['youarehere']            = 'Här är du';
$lang['lastmod']               = 'Senast uppdaterad';
$lang['by']                    = 'av';
$lang['deleted']               = 'raderad';
$lang['created']               = 'skapad';
$lang['restored']              = 'tidigare version återställd';
$lang['external_edit']         = 'extern redigering';
$lang['summary']               = 'Redigeringskommentar';
$lang['mail_newpage']          = 'sida tillagd:';
$lang['mail_changed']          = 'sida ändrad:';
$lang['mail_new_user']         = 'Ny användare:';
$lang['mail_upload']           = 'fil uppladdad:';
$lang['nosmblinks']            = 'Länkning till Windowsresurser fungerar bara med Microsofts Internet Explorer.\nDu kan klippa och klistra in länken om du använder en annan webbläsare än MSIE..';
$lang['qb_alert']              = 'Ange den text du vill formattera.\nDen kommer att läggas till i slutet av dokumentet.';
$lang['qb_bold']               = 'Fet text';
$lang['qb_italic']             = 'Kursiv text';
$lang['qb_underl']             = 'Understruken text';
$lang['qb_code']               = 'Kodtext';
$lang['qb_strike']             = 'Överstruken text';
$lang['qb_h1']                 = 'Rubrik nivå 1';
$lang['qb_h2']                 = 'Rubrik nivå 2';
$lang['qb_h3']                 = 'Rubrik nivå 3';
$lang['qb_h4']                 = 'Rubrik nivå 4';
$lang['qb_h5']                 = 'Rubrik nivå 5';
$lang['qb_link']               = 'Intern Länk';
$lang['qb_extlink']            = 'Extern Länk';
$lang['qb_hr']                 = 'Horisontell linje';
$lang['qb_ol']                 = 'Punkt i sorterad lista';
$lang['qb_ul']                 = 'Punkt i osorterad lista';
$lang['qb_media']              = 'Lägg till bilder och andra filer';
$lang['qb_sig']                = 'Infoga signatur';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Specialtecken';
$lang['del_confirm']           = 'Vill du verkligen radera?';
$lang['admin_register']        = 'Lägg till ny användare';
$lang['metaedit']              = 'Redigera metadata';
$lang['metasaveerr']           = 'Skrivning av metadata misslyckades';
$lang['metasaveok']            = 'Metadata sparad';
$lang['img_backto']            = 'Tillbaka till';
$lang['img_title']             = 'Rubrik';
$lang['img_caption']           = 'Bildtext';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Filnamn';
$lang['img_fsize']             = 'Storlek';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Nyckelord';
$lang['subscribe_success']     = 'Lade till %s i prenumerationslistan för %s';
$lang['subscribe_error']       = 'Fel vid tillägg av %s i prenumerationslistan för %s';
$lang['subscribe_noaddress']   = 'Det finns ingen adress knuten till ditt konto, det går inte att lägga till dig i prenumerationslistan';
$lang['unsubscribe_success']   = 'Tog bort %s från prenumerationslistan för %s';
$lang['unsubscribe_error']     = 'Fel vid borttagning %s från prenumerationslistan list för %s';
$lang['authmodfailed']         = 'Felaktiga inställningar för användarautentisering. Var vänlig meddela wikiadministratören.';
$lang['authtempfail']          = 'Tillfälligt fel på användarautentisering. Om felet kvarstår, var vänlig meddela wikiadministratören.';
$lang['i_chooselang']          = 'Välj språk';
$lang['i_installer']           = 'Installation av DokuWiki';
$lang['i_wikiname']            = 'Wikins namn';
$lang['i_enableacl']           = 'Aktivera behörighetslistan (ACL) (rekommenderas)';
$lang['i_superuser']           = 'Användarnamn för administratören';
$lang['i_problems']            = 'Installationsprogrammet hittade några problem som visas nedan. Du kan inte fortsätta innan du har fixat dem.';
$lang['i_modified']            = 'Av säkerhetsskäl fungerar det här skriptet bara med en ny och omodifierad installation av Dokuwiki.
                         Du får antingen packa upp det nedladdade paketet på nytt, eller konsultera de kompletta
                         <a href="http://wiki.splitbrain.org/wiki:install">instruktionerna för installation av Dokuwiki</a>';
$lang['i_funcna']              = 'PHP-funktionen <code>%s</code> är inte tillgänglig. Kanske ditt webbhotell har avaktiverat den av någon anledning?';
$lang['i_phpver']              = 'Din PHP-version <code>%s</code> är lägre än vad som krävs <code>%s</code>. Du behöver uppgradera din PHP-installation.';
$lang['i_permfail']            = '<code>%s</code> är inte skrivbar av DokuWiki. Du behöver ändra filskyddet på den här katalogen!';
$lang['i_confexists']          = '<code>%s</code> finns redan';
$lang['i_writeerr']            = 'Kan inte skapa <code>%s</code>. Kontrollera filskyddet på kataloger/filer och skapa filen manuellt.';
$lang['i_badhash']             = 'okänd eller ändrad dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - felaktig eller blank';
$lang['i_success']             = 'Konfigurationen avslutades utan fel. Du kan radera filen install.php nu. Fortsätt till
                        <a href="doku.php">din nya DokuWiki</a>.';
$lang['i_failure']             = 'Fel uppstod vid skrivning av konfigurationsfilerna. Du kan behöva ordna till dem manuellt innan
                         du kan använda <a href="doku.php">din nya DokuWiki</a>.';
$lang['i_policy']              = 'Initial ACL-policy';
$lang['i_pol0']                = 'Öppen wiki (alla får läsa, skriva och ladda upp filer)';
$lang['i_pol1']                = 'Publik wiki (alla får läsa, registrerade användare för skriva och ladda upp filer)';
$lang['i_pol2']                = 'Sluten wiki (endast registrerade användare får läsa, skriva och ladda upp filer)';
$lang['i_retry']               = 'Försök igen';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/sv/lang.php <==
<?php
/**
 * Swedish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Joaquim Homrighausen <joho@webbplatsen.se>
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell[at]mydata.se>
 * @author Dennis Karlsson
 * @author Tormod Otter Johansson <tormod@latast.se>
 * @author emil@sys.nu
 * @author Pontus Bergendahl <pontus.bergendahl@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '”';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '’';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Redigera sidan';
$lang['btn_source']            = 'Visa källkod';
$lang['btn_show']              = 'Visa sidan';
$lang['btn_create']            = 'Skapa sidan';
$lang['btn_search']            = 'Sök';
$lang['btn_save']              = 'Spara';
$lang['btn_preview']           = 'Granska';
$lang['btn_top']               = 'Till början av sidan';
$lang['btn_newer']             = '<< nyare';
$lang['btn_older']             = 'äldre >>';
$lang['btn_revs']              = 'Historik';
$lang['btn_recent']            = 'Nyligen ändrat';
$lang['btn_upload']            = 'Ladda upp';
$lang['btn_cancel']            = 'Avbryt';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Redigera';
$lang['btn_login']             = 'Logga in';
$lang['btn_logout']            = 'Logga ut';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Uppdatera';
$lang['btn_delete']            = 'Radera';
$lang['btn_back']              = 'Tillbaka';
$lang['btn_backlink']          = 'Tillbakalänkar';
$lang['btn_backtomedia']       = 'Tillbaka till val av Mediafil';
$lang['btn_subscribe']         = 'Prenumerera på ändringar';
$lang['btn_unsubscribe']       = 'Säg upp prenumeration på ändringar';
$lang['btn_subscribens']       = 'Prenumerera på namnrymdsändringar';
$lang['btn_unsubscribens']     = 'Sluta prenumerera på namnrymdsändringar
';
$lang['btn_profile']           = 'Uppdatera profil';
$lang['btn_reset']             = 'Återställ';
$lang['btn_resendpwd']         = 'Skicka nytt lösenord';
$lang['btn_draft']             = 'Redigera utkast';
$lang['btn_recover']           = 'Återskapa utkast';
$lang['btn_draftdel']          = 'Radera utkast';
$lang['loggedinas']            = 'Inloggad som';
$lang['user']                  = 'Användarnamn';
$lang['pass']                  = 'Lösenord';
$lang['newpass']               = 'Nytt lösenord';
$lang['oldpass']               = 'Bekräfta nuvarande lösenord';
$lang['passchk']               = 'en gång till';
$lang['remember']              = 'Kom ihåg mig';
$lang['fullname']              = 'Namn';
$lang['email']                 = 'E-post';
$lang['register']              = 'Registrera';
$lang['profile']               = 'Användarprofil';
$lang['badlogin']              = 'Felaktigt användarnamn eller lösenord.';
$lang['minoredit']             = 'Små ändringar';
$lang['draftdate']             = 'Utkast automatiskt sparat';
$lang['nosecedit']             = 'Sidan ändrades medan du skrev, sektionsinformationen var inte uppdaterad. Laddar hela sidan istället.';
$lang['regmissing']            = 'Du måste fylla i alla fälten.';
$lang['reguexists']            = 'Det finns redan en användare med det användarnamnet.';
$lang['regsuccess']            = 'Användarkontot skapat, lösenordet har skickats via e-post.';
$lang['regsuccess2']           = 'Användarkontot skapat.';
$lang['regmailfail']           = 'Ett fel uppstod när ditt lösenord skulle skickas via e-post. Var god kontakta administratören!';
$lang['regbadmail']            = 'Den angivna e-postadressen verkar vara ogiltig - om du anser detta felaktigt, var god kontakta administratören';
$lang['regbadpass']            = 'De två angivna lösenorden är inte identiska. Försök igen.';
$lang['regpwmail']             = 'Ditt DokuWikilösenord';
$lang['reghere']               = 'Har du inte ett konto än? Skaffa ett';
$lang['profna']                = 'Denna wiki stödjer inte ändringar av profiler';
$lang['profnochange']          = 'Ingenting ändrades, inget att göra.';
$lang['profnoempty']           = 'Namn och e-postadress måste fyllas i.';
$lang['profchanged']           = 'Användarprofilen uppdaterad.';
$lang['pwdforget']             = 'Glömt ditt lösenord? Ordna ett nytt';
$lang['resendna']              = 'Den här wikin stödjer inte utskick av lösenord.';
$lang['resendpwd']             = 'Skicka nytt lösenord för';
$lang['resendpwdmissing']      = 'Du måste fylla i alla fält.';
$lang['resendpwdnouser']       = 'Den här användaren hittas inte i databasen.';
$lang['resendpwdbadauth']      = 'Den här verifieringskoden är inte giltig. Kontrollera att du använde hela verifieringslänken.';
$lang['resendpwdconfirm']      = 'En verifieringslänk har skickats med e-post.';
$lang['resendpwdsuccess']      = 'Ditt nya lösenord har skickats med e-post.';
$lang['license']               = 'Om inte annat angivet, innehållet i denna wiki är licensierat under följande licenser:';
$lang['licenseok']             = 'Notera: Genom att ändra i denna sidan så accepterar du att licensiera ditt bidrag under följande licenser:';
$lang['txt_upload']            = 'Välj fil att ladda upp';
$lang['txt_filename']          = 'Ladda upp som (ej obligatoriskt)';
$lang['txt_overwrt']           = 'Skriv över befintlig fil';
$lang['lockedby']              = 'Låst av';
$lang['lockexpire']            = 'Lås upphör att gälla';
$lang['willexpire']            = 'Ditt redigeringslås för detta dokument kommer snart att upphöra.\nFör att undvika versionskonflikter bör du förhandsgranska ditt dokument för att förlänga redigeringslåset.';
$lang['notsavedyet']           = 'Det finns ändringar som inte är sparade.\nÄr du säker på att du vill fortsätta?';
$lang['rssfailed']             = 'Ett fel uppstod när detta RSS-flöde skulle hämtas: ';
$lang['nothingfound']          = 'Inga filer hittades.';
$lang['mediaselect']           = 'Mediafiler';
$lang['fileupload']            = 'Ladda upp mediafiler';
$lang['uploadsucc']            = 'Uppladdningen lyckades';
$lang['uploadfail']            = 'Uppladdningen misslyckades, fel filskydd?';
$lang['uploadwrong']           = 'Uppladdning nekad. Filändelsen är inte tillåten!';
$lang['uploadexist']           = 'Filen finns redan. Gjorde ingenting.';
$lang['uploadbadcontent']      = 'Det uppladdade innehållet stämde inte överens med filändelsen %s.';
$lang['uploadspam']            = 'Uppladdningen stoppades av spärrlistan för spam.';
$lang['uploadxss']             = 'Uppladdningen stoppades på grund av eventuellt skadligt innehåll.';
$lang['uploadsize']            = 'Den uppladdade filen är för stor. (max. %s)';
$lang['deletesucc']            = 'Filen "%s" har raderats.';
$lang['deletefail']            = 'Kunde inte radera "%s" - kontrollera filskydd.';
$lang['mediainuse']            = 'Filen "%s" har inte raderats - den används fortfarande.';
$lang['namespaces']            = 'Namnrymder';
$lang['mediafiles']            = 'Tillgängliga filer i';
$lang['js']['keepopen']        = 'Lämna fönstret öppet efter val av fil';
$lang['js']['hidedetails']     = 'Dölj detaljer';
$lang['js']['nosmblinks']      = 'Länkning till Windowsresurser fungerar bara med Microsofts Internet Explorer.
Du kan klippa och klistra in länken om du använder en annan webbläsare än MSIE..';
$lang['js']['mu_btn']          = 'Ladda upp flera filer samtidigt';
$lang['mediausage']            = 'Använd följande syntax för att referera till denna fil:';
$lang['mediaview']             = 'Visa originalfilen';
$lang['mediaroot']             = 'rot';
$lang['mediaupload']           = 'Här kan du ladda upp en fil till den nuvarande namnrymden. För att skapa undernamnrymder, skriv dem före filnamnet under "Ladda upp som". Separera namnrymd och filnamn med kolon.';
$lang['mediaextchange']        = 'Filändelsen ändrad från .%s till .%s!';
$lang['reference']             = 'Referenser till';
$lang['ref_inuse']             = 'Filen kan inte raderas eftersom den fortfarande används av följande sidor:';
$lang['ref_hidden']            = 'Vissa referenser är på sidor som du inte har rätt att läsa';
$lang['hits']                  = 'Träffar';
$lang['quickhits']             = 'Matchande sidnamn';
$lang['toc']                   = 'Innehållsförteckning';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Din version';
$lang['diff']                  = 'visa skillnader mot aktuell version';
$lang['diff2']                 = 'Visa skillnader mellan valda versioner';
$lang['line']                  = 'Rad';
$lang['breadcrumb']            = 'Spår';
$lang['youarehere']            = 'Här är du';
$lang['lastmod']               = 'Senast uppdaterad';
$lang['by']                    = 'av';
$lang['deleted']               = 'raderad';
$lang['created']               = 'skapad';
$lang['restored']              = 'tidigare version återställd';
$lang['external_edit']         = 'extern redigering';
$lang['summary']               = 'Redigeringskommentar';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> behövs för att visa detta innehåll.';
$lang['mail_newpage']          = 'sida tillagd:';
$lang['mail_changed']          = 'sida ändrad:';
$lang['mail_new_user']         = 'Ny användare:';
$lang['mail_upload']           = 'fil uppladdad:';
$lang['qb_alert']              = 'Ange den text du vill formattera.\nDen kommer att läggas till i slutet av dokumentet.';
$lang['qb_bold']               = 'Fet text';
$lang['qb_italic']             = 'Kursiv text';
$lang['qb_underl']             = 'Understruken text';
$lang['qb_code']               = 'Kodtext';
$lang['qb_strike']             = 'Överstruken text';
$lang['qb_h1']                 = 'Rubrik nivå 1';
$lang['qb_h2']                 = 'Rubrik nivå 2';
$lang['qb_h3']                 = 'Rubrik nivå 3';
$lang['qb_h4']                 = 'Rubrik nivå 4';
$lang['qb_h5']                 = 'Rubrik nivå 5';
$lang['qb_link']               = 'Intern Länk';
$lang['qb_extlink']            = 'Extern Länk';
$lang['qb_hr']                 = 'Horisontell linje';
$lang['qb_ol']                 = 'Punkt i sorterad lista';
$lang['qb_ul']                 = 'Punkt i osorterad lista';
$lang['qb_media']              = 'Lägg till bilder och andra filer';
$lang['qb_sig']                = 'Infoga signatur';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Specialtecken';
$lang['del_confirm']           = 'Vill du verkligen radera?';
$lang['admin_register']        = 'Lägg till ny användare';
$lang['metaedit']              = 'Redigera metadata';
$lang['metasaveerr']           = 'Skrivning av metadata misslyckades';
$lang['metasaveok']            = 'Metadata sparad';
$lang['img_backto']            = 'Tillbaka till';
$lang['img_title']             = 'Rubrik';
$lang['img_caption']           = 'Bildtext';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Filnamn';
$lang['img_fsize']             = 'Storlek';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Nyckelord';
$lang['subscribe_success']     = 'Lade till %s i prenumerationslistan för %s';
$lang['subscribe_error']       = 'Fel vid tillägg av %s i prenumerationslistan för %s';
$lang['subscribe_noaddress']   = 'Det finns ingen adress knuten till ditt konto, det går inte att lägga till dig i prenumerationslistan';
$lang['unsubscribe_success']   = 'Tog bort %s från prenumerationslistan för %s';
$lang['unsubscribe_error']     = 'Fel vid borttagning %s från prenumerationslistan list för %s';
$lang['authmodfailed']         = 'Felaktiga inställningar för användarautentisering. Var vänlig meddela wikiadministratören.';
$lang['authtempfail']          = 'Tillfälligt fel på användarautentisering. Om felet kvarstår, var vänlig meddela wikiadministratören.';
$lang['i_chooselang']          = 'Välj språk';
$lang['i_installer']           = 'Installation av DokuWiki';
$lang['i_wikiname']            = 'Wikins namn';
$lang['i_enableacl']           = 'Aktivera behörighetslistan (ACL) (rekommenderas)';
$lang['i_superuser']           = 'Användarnamn för administratören';
$lang['i_problems']            = 'Installationsprogrammet hittade några problem som visas nedan. Du kan inte fortsätta innan du har fixat dem.';
$lang['i_modified']            = 'Av säkerhetsskäl fungerar det här skriptet bara med en ny och omodifierad installation av Dokuwiki.
                         Du får antingen packa upp det nedladdade paketet på nytt, eller konsultera de kompletta
                         <a href="http://dokuwiki.org/install">instruktionerna för installation av Dokuwiki</a>';
$lang['i_funcna']              = 'PHP-funktionen <code>%s</code> är inte tillgänglig. Kanske ditt webbhotell har avaktiverat den av någon anledning?';
$lang['i_phpver']              = 'Din PHP-version <code>%s</code> är lägre än vad som krävs <code>%s</code>. Du behöver uppgradera din PHP-installation.';
$lang['i_permfail']            = '<code>%s</code> är inte skrivbar av DokuWiki. Du behöver ändra filskyddet på den här katalogen!';
$lang['i_confexists']          = '<code>%s</code> finns redan';
$lang['i_writeerr']            = 'Kan inte skapa <code>%s</code>. Kontrollera filskyddet på kataloger/filer och skapa filen manuellt.';
$lang['i_badhash']             = 'okänd eller ändrad dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - felaktig eller blank';
$lang['i_success']             = 'Konfigurationen avslutades utan fel. Du kan radera filen install.php nu. Fortsätt till
                        <a href="doku.php">din nya DokuWiki</a>.';
$lang['i_failure']             = 'Fel uppstod vid skrivning av konfigurationsfilerna. Du kan behöva ordna till dem manuellt innan
                         du kan använda <a href="doku.php">din nya DokuWiki</a>.';
$lang['i_policy']              = 'Initial ACL-policy';
$lang['i_pol0']                = 'Öppen wiki (alla får läsa, skriva och ladda upp filer)';
$lang['i_pol1']                = 'Publik wiki (alla får läsa, registrerade användare för skriva och ladda upp filer)';
$lang['i_pol2']                = 'Sluten wiki (endast registrerade användare får läsa, skriva och ladda upp filer)';
$lang['i_retry']               = 'Försök igen';
$lang['mu_intro']              = 'Här kan du ladda upp flera filer på en gång. Klicka på bläddra-knappen för att lägga till dem i kön. Tryck på ladda upp när du är klar.';
$lang['mu_gridname']           = 'Filnamn';
$lang['mu_gridsize']           = 'Storlek';
$lang['mu_gridstat']           = 'Status';
$lang['mu_namespace']          = 'Namnrymd';
$lang['mu_browse']             = 'Bläddra';
$lang['mu_toobig']             = 'för stor';
$lang['mu_ready']              = 'redo att ladda upp';
$lang['mu_done']               = 'komplett';
$lang['mu_fail']               = 'misslyckades';
$lang['mu_authfail']           = 'sessionen över tid';
$lang['mu_progress']           = '@PCT@% uppladdade';
$lang['mu_filetypes']          = 'Tillåtna filtyper';
$lang['recent_global']         = 'Du bevakar ändringar i namnrymden <b>%s</b>. Du kan också titta på <a href="%s">senaste ändringar för hela wikin</a>.';
